jactorch.vision.peak
====================

.. automodule:: jactorch.vision.peak

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      peak_local_max
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: peak_local_max


